
%Main function that performs isotopomer calculations. First mass isotopomer distribution is corrected, then positional isotopomer distribution is computed
%inputfile = name of the input file
%outputfile = name of the outputfile
function y = Calculate(inputFile,outputFile)
    
    global labelType;
    global fragments;
    global peakWarning;
   % global isDaughterScan;
    
 
    Initialize; % really unnecessary to execute every time..
    fragments = ReadFile(inputFile, 0);
    peakWarning = ' ';
    
    % correct mass isotoper distribution
    
    indexOflabel = -1;
    for i = 1 : length(fragments)
        for j = 1:length(fragments{i}.formula)
            if fragments{i}.formula{j} == labelType
                indexOfLabel = j;
                break;
            end
        end
        if indexOfLabel == -1
            myError('No labels in fragment!','Error in Calculate');
        end
        tempFormula = fragments{i}.formula;
        tempFormula(indexOfLabel)= [];
        tempAtomCount = fragments{i}.atomCount;
        tempAtomCount(indexOfLabel) = [];
        tempIntensities = fragments{i}.intensities;
        
        peakWarning = strcat(peakWarning,CheckSpectras(i,indexOfLabel,tempIntensities));
        
        if (length(tempFormula) == 0)
            naturalAbundances =zeros(1,length(fragments{i}.intensities));
            naturalAbundances(1,1) = 1;
        else
            %compute the natural abundances of non-carbon atoms of the current fragment                                                                           
            naturalAbundances = CalculateNatIsotopDistr(tempFormula, tempAtomCount,length(fragments{i}.intensities) - 1); 
        end
        %store the natural abundances of the complete molecule
        if (i == 1)
                origAbundances = naturalAbundances;
                origIntensities = fragments{1}.intensities / sum(fragments{1}.intensities);
        end
        if i > 1 & fragments{i}.peak > -1 & length(tempFormula) > 0%daughter ion scanning is used. have to compute conditional natural abundances
                naturalAbundances = CalculateCondIsotDistr(i,naturalAbundances);   
        end
       %correct the measured spectra of the current fragment
        fragments{i}.intensities = CalculateMassIsotopDistr(naturalAbundances, fragments{i}.intensities, fragments{i}.atomCount(indexOfLabel));
        
    end
    
    fragments = ConvertToRelativeIntensities(fragments, origIntensities);
    
    % calculate positional isotopomers
    posIsotops = CalculatePosIsotops(origAbundances);
    
    %POISTETAAN??
    %if isDaughterScan == 1 %if daughter scan is used, posIsotops contains distribution
    %    % remove negative proportions, should not be needed
    %    negativePosits = find(posIsotops(:,size(posIsotops,2)) < 0);
    %    for i = 1 : length(negativePosits)
    %        if posIsotops(negativePosits(i),size(posIsotops,2)) < - 0.1  %error in input file
    %            warndlg('Positional isotopomer distribution contains negative values < - 0.1. Error in input file?', 'Warning');   
    %        end
    %        posIsotops(negativePosits(i),size(posIsotops,2)) = 0;
    %    end
    
        %normalize, should not be needed
    %    posIsotops(:,size(posIsotops,2)) = posIsotops(:,size(posIsotops,2)) / sum(posIsotops(:,size(posIsotops,2)));
    %end  
    
    %write the results
    WriteFiles(posIsotops,outputFile);
